@@ -1,12 +1,23 @@
 from sklearn.model_selection import GridSearchCV
-def hyperTune(classifier, parameters, X_train, y_train, cv_folds, tune_mode, isReg=False, all_mode=False):
+
+
+def hyperTune(
+    classifier,
+    parameters,
+    X_train,
+    y_train,
+    cv_folds,
+    tune_mode,
+    isReg=False,
+    all_mode=False,
+):
     """
     Takes classifier, tune-parameters, Training Data and no. of folds as input and Performs GridSearch Crossvalidation.
     """
     try:
-        scoring = 'accuracy'
+        scoring = "accuracy"
         if isReg:
-            scoring = 'r2'
+            scoring = "r2"
         grid_search = GridSearchCV(
             estimator=classifier,
             param_grid=parameters,
@@ -18,9 +29,9 @@ def hyperTune(classifier, parameters, X_train, y_train, cv_folds, tune_mode, isR
         best_accuracy = grid_search.best_score_
         best_parameters = grid_search.best_params_
         if not all_mode:
-            print("Best Accuracy: {:.2f} %".format(best_accuracy*100))
+            print("Best Accuracy: {:.2f} %".format(best_accuracy * 100))
             print("Best Parameters:", best_parameters)
-            print('Applying Grid Search Cross validation [', u'\u2713', ']\n')
+            print("Applying Grid Search Cross validation [", u"\u2713", "]\n")
         return best_parameters, best_accuracy
     except Exception as error:
-        print('HyperParam Tuning Failed with Error: ', error, '\n')
+        print("HyperParam Tuning Failed with Error: ", error, "\n")
