@@ -2,12 +2,20 @@ import tensorflow as tf
 from catboost import CatBoostRegressor
 from lightgbm import LGBMRegressor
 from luciferml.supervised.utils.regression_params import *
-from sklearn.ensemble import (AdaBoostRegressor, BaggingRegressor,
-                              ExtraTreesRegressor, GradientBoostingRegressor,
-                              RandomForestRegressor)
+from sklearn.ensemble import (
+    AdaBoostRegressor,
+    BaggingRegressor,
+    ExtraTreesRegressor,
+    GradientBoostingRegressor,
+    RandomForestRegressor,
+)
 from sklearn.kernel_ridge import KernelRidge
-from sklearn.linear_model import (BayesianRidge, ElasticNet, LinearRegression,
-                                  SGDRegressor)
+from sklearn.linear_model import (
+    BayesianRidge,
+    ElasticNet,
+    LinearRegression,
+    SGDRegressor,
+)
 from sklearn.neighbors import KNeighborsRegressor
 from sklearn.svm import SVR
 from sklearn.tree import DecisionTreeRegressor
@@ -15,18 +23,33 @@ from xgboost import XGBRegressor
 
 
 def regressionPredictor(
-        predictor, params, X_train, X_val, y_train, y_val, epochs, hidden_layers,
-        input_activation, loss,
-        batch_size, validation_split, optimizer, output_units, input_units,
-        tune_mode, dropout_rate=0, all_mode=False, verbose=False
+    predictor,
+    params,
+    X_train,
+    X_val,
+    y_train,
+    y_val,
+    epochs,
+    hidden_layers,
+    input_activation,
+    loss,
+    batch_size,
+    validation_split,
+    optimizer,
+    output_units,
+    input_units,
+    tune_mode,
+    dropout_rate=0,
+    all_mode=False,
+    verbose=False,
 ):
     """
     Takes Predictor string , parameters , Training and Validation set and Returns a regressor for the Choosen Predictor.
     """
     try:
-        if predictor == 'lin':
+        if predictor == "lin":
             if not all_mode:
-                print('Training Logistic Regression on Training Set [*]\n')
+                print("Training Logistic Regression on Training Set [*]\n")
             regressor = LinearRegression(**params)
             if tune_mode == 1:
                 parameters = parameters_lin
@@ -35,10 +58,11 @@ def regressionPredictor(
             elif tune_mode == 3:
                 parameters = parameters_lin
 
-        elif predictor == 'sgd':
+        elif predictor == "sgd":
             if not all_mode:
                 print(
-                    'Training Stochastic Gradient Descent Regressor on Training Set [*]\n')
+                    "Training Stochastic Gradient Descent Regressor on Training Set [*]\n"
+                )
             regressor = SGDRegressor(**params)
             if tune_mode == 1:
                 parameters = parameters_sgd_1
@@ -47,9 +71,9 @@ def regressionPredictor(
             elif tune_mode == 3:
                 parameters = parameters_sgd_3
 
-        elif predictor == 'krr':
+        elif predictor == "krr":
             if not all_mode:
-                print('Training Kernel Ridge Regressor on Training Set [*]\n')
+                print("Training Kernel Ridge Regressor on Training Set [*]\n")
             regressor = KernelRidge(**params)
             if tune_mode == 1:
                 parameters = parameters_ker_1
@@ -58,9 +82,9 @@ def regressionPredictor(
             elif tune_mode == 3:
                 parameters = parameters_ker_3
 
-        elif predictor == 'elas':
+        elif predictor == "elas":
             if not all_mode:
-                print('Training ElasticNet Regressor on Training Set [*]\n')
+                print("Training ElasticNet Regressor on Training Set [*]\n")
             regressor = ElasticNet(**params)
             if tune_mode == 1:
                 parameters = parameters_elas
@@ -69,9 +93,9 @@ def regressionPredictor(
             elif tune_mode == 3:
                 parameters = parameters_elas
 
-        elif predictor == 'br':
+        elif predictor == "br":
             if not all_mode:
-                print('Training BayesianRidge Regressor on Training Set [*]\n')
+                print("Training BayesianRidge Regressor on Training Set [*]\n")
             regressor = BayesianRidge(**params)
             if tune_mode == 1:
                 parameters = parameters_br
@@ -80,9 +104,9 @@ def regressionPredictor(
             elif tune_mode == 3:
                 parameters = parameters_br
 
-        elif predictor == 'svr':
+        elif predictor == "svr":
             if not all_mode:
-                print('Training Support Vector Machine on Training Set [*]\n')
+                print("Training Support Vector Machine on Training Set [*]\n")
             regressor = SVR(**params)
             if tune_mode == 1:
                 parameters = parameters_svr_1
@@ -91,9 +115,9 @@ def regressionPredictor(
             elif tune_mode == 3:
                 parameters = parameters_svr_3
 
-        elif predictor == 'knr':
+        elif predictor == "knr":
             if not all_mode:
-                print('Training KNeighbors Regressor on Training Set [*]\n')
+                print("Training KNeighbors Regressor on Training Set [*]\n")
             regressor = KNeighborsRegressor(**params)
             if tune_mode == 1:
                 parameters = parameters_knr_1
@@ -102,9 +126,9 @@ def regressionPredictor(
             elif tune_mode == 3:
                 parameters = parameters_knr_3
 
-        elif predictor == 'dt':
+        elif predictor == "dt":
             if not all_mode:
-                print('Training Decision Tree regressor on Training Set [*]\n')
+                print("Training Decision Tree regressor on Training Set [*]\n")
             regressor = DecisionTreeRegressor(**params)
             if tune_mode == 1:
                 parameters = parameters_dt_1
@@ -113,9 +137,9 @@ def regressionPredictor(
             elif tune_mode == 3:
                 parameters = parameters_dt_3
 
-        elif predictor == 'rfr':
+        elif predictor == "rfr":
             if not all_mode:
-                print('Training Random Forest regressor on Training Set [*]\n')
+                print("Training Random Forest regressor on Training Set [*]\n")
             regressor = RandomForestRegressor(**params)
             if tune_mode == 1:
                 parameters = parameters_rfr_1
@@ -124,10 +148,9 @@ def regressionPredictor(
             elif tune_mode == 3:
                 parameters = parameters_rfr_3
 
-        elif predictor == 'gbr':
+        elif predictor == "gbr":
             if not all_mode:
-                print(
-                    'Training Gradient Boosting Regressor  on Training Set [*]\n')
+                print("Training Gradient Boosting Regressor  on Training Set [*]\n")
             regressor = GradientBoostingRegressor(**params)
             if tune_mode == 1:
                 parameters = parameters_gbr_1
@@ -136,9 +159,9 @@ def regressionPredictor(
             elif tune_mode == 3:
                 parameters = parameters_gbr_3
 
-        elif predictor == 'ada':
+        elif predictor == "ada":
             if not all_mode:
-                print('Training AdaBoost Regressor on Training Set [*]\n')
+                print("Training AdaBoost Regressor on Training Set [*]\n")
             regressor = AdaBoostRegressor(**params)
             if tune_mode == 1:
                 parameters = parameters_ada_1
@@ -147,9 +170,9 @@ def regressionPredictor(
             elif tune_mode == 3:
                 parameters = parameters_ada_3
 
-        elif predictor == 'bag':
+        elif predictor == "bag":
             if not all_mode:
-                print('Training Bagging Regressor on Training Set [*]\n')
+                print("Training Bagging Regressor on Training Set [*]\n")
             regressor = BaggingRegressor(**params)
             if tune_mode == 1:
                 parameters = parameters_bag_1
@@ -158,9 +181,9 @@ def regressionPredictor(
             elif tune_mode == 3:
                 parameters = parameters_bag_3
 
-        elif predictor == 'extr':
+        elif predictor == "extr":
             if not all_mode:
-                print('Training Extra Trees Regressor on Training Set [*]\n')
+                print("Training Extra Trees Regressor on Training Set [*]\n")
             regressor = ExtraTreesRegressor(**params)
             if tune_mode == 1:
                 parameters = parameters_extr_1
@@ -169,9 +192,9 @@ def regressionPredictor(
             elif tune_mode == 3:
                 parameters = parameters_extr_3
 
-        elif predictor == 'xgb':
+        elif predictor == "xgb":
             if not all_mode:
-                print('Training XGBregressor on Training Set [*]\n')
+                print("Training XGBregressor on Training Set [*]\n")
             regressor = XGBRegressor(**params)
             if tune_mode == 1:
                 parameters = parameters_xgb_1
@@ -180,9 +203,9 @@ def regressionPredictor(
             elif tune_mode == 3:
                 parameters = parameters_xgb_3
 
-        elif predictor == 'lgbm':
+        elif predictor == "lgbm":
             if not all_mode:
-                print('Training LGBMRegressor on Training Set [*]\n')
+                print("Training LGBMRegressor on Training Set [*]\n")
             regressor = LGBMRegressor(**params)
             if tune_mode == 1:
                 parameters = parameters_lgbm_1
@@ -191,10 +214,10 @@ def regressionPredictor(
             elif tune_mode == 3:
                 parameters = parameters_lgbm_3
 
-        elif predictor == 'cat':
+        elif predictor == "cat":
             if not all_mode:
-                print('Training CatBoost Regressor on Training Set [*]\n')
-            params['verbose'] = verbose
+                print("Training CatBoost Regressor on Training Set [*]\n")
+            params["verbose"] = verbose
             regressor = CatBoostRegressor(**params)
             if tune_mode == 1:
                 parameters = parameters_cat
@@ -203,38 +226,49 @@ def regressionPredictor(
             elif tune_mode == 3:
                 parameters = parameters_cat
 
-        elif predictor == 'ann':
+        elif predictor == "ann":
+
             def build_ann_model(input_units, optimizer, rate):
                 try:
                     regressor = tf.keras.models.Sequential()
                     for i in range(0, hidden_layers):
-                        regressor.add(tf.keras.layers.Dense(
-                            units=input_units, activation=input_activation))
+                        regressor.add(
+                            tf.keras.layers.Dense(
+                                units=input_units, activation=input_activation
+                            )
+                        )
                         regressor.add(tf.keras.layers.Dropout(rate=rate))
-                    regressor.add(tf.keras.layers.Dense(
-                        units=output_units))
-                    regressor.compile(optimizer=optimizer,
-                                      loss=loss)
+                    regressor.add(tf.keras.layers.Dense(units=output_units))
+                    regressor.compile(optimizer=optimizer, loss=loss)
                     return regressor
 
                 except Exception as error:
-                    print('ANN Build Failed with error :', error, '\n')
+                    print("ANN Build Failed with error :", error, "\n")
+
             if not all_mode:
-                print('Training ANN on Training Set [*]\n')
+                print("Training ANN on Training Set [*]\n")
             regressor = build_ann_model(input_units, optimizer, dropout_rate)
 
             if verbose == False:
                 verbose = 0
             if verbose == True:
-                verbose = 'auto'
+                verbose = "auto"
             ann_history = regressor.fit(
-                X_train, y_train, validation_split=validation_split,
-                validation_data=(
-                    X_val, y_val), epochs=epochs, batch_size=batch_size, verbose=verbose
+                X_train,
+                y_train,
+                validation_split=validation_split,
+                validation_data=(X_val, y_val),
+                epochs=epochs,
+                batch_size=batch_size,
+                verbose=verbose,
             )
             regressor_wrap = tf.keras.wrappers.scikit_learn.KerasRegressor(
-                build_fn=build_ann_model, input_units=input_units,
-                epochs=epochs, batch_size=batch_size, optimizer=optimizer, rate=dropout_rate
+                build_fn=build_ann_model,
+                input_units=input_units,
+                epochs=epochs,
+                batch_size=batch_size,
+                optimizer=optimizer,
+                rate=dropout_rate,
             )
             if tune_mode == 1:
                 parameters = parameters_ann_1
@@ -243,8 +277,8 @@ def regressionPredictor(
             elif tune_mode == 3:
                 parameters = parameters_ann_3
 
-        if predictor == 'ann':
+        if predictor == "ann":
             return (parameters, regressor, regressor_wrap)
         return (parameters, regressor)
     except Exception as error:
-        print('Model Build Failed with error :', error, '\n')
+        print("Model Build Failed with error :", error, "\n")
